# cc.SCPI

[![API-Docs-status](https://img.shields.io/github/actions/workflow/status/uncertainty-cc/SCPI-Python/build-docs.yaml?branch=main&style=flat-square&label=Docs&logo=googledocs&logoColor=fff)](https://uncertainty.cc/SCPI-Python/cc/scpi.html)

The Standard Commands for Programmable Instruments (SCPI) defines a standard for syntax and commands to use in controlling programmable test and measurement devices. This Python module provides a wrapper for controlling various lab instruments.

## Installation

```bash
pip install cc-scpi
```
